@@ -239,7 +239,7 @@ __all__ = ["compile", "escape", "findall", "finditer", "fullmatch", "match",
   "U", "UNICODE", "V0", "VERSION0", "V1", "VERSION1", "X", "VERBOSE", "W",
   "WORD", "error", "Regex"]
 
-__version__ = "2.4.124"
+__version__ = "2.4.125"
 
 # --------------------------------------------------------------------
 # Public interface.
@@ -353,12 +353,14 @@ def template(pattern, flags=0):
     "Compile a template pattern, returning a pattern object."
     return _compile(pattern, flags | TEMPLATE)
 
-def escape(pattern, special_only=True):
+def escape(pattern, special_only=True, literal_spaces=False):
     "Escape all non-alphanumeric characters or special characters in pattern."
     s = []
     if special_only:
         for c in pattern:
-            if c in _METACHARS or c.isspace():
+            if c == " " and literal_spaces:
+                s.append(c)
+            elif c in _METACHARS or c.isspace():
                 s.append("\\")
                 s.append(c)
             elif c == "\x00":
@@ -367,7 +369,9 @@ def escape(pattern, special_only=True):
                 s.append(c)
     else:
         for c in pattern:
-            if c in _ALNUM:
+            if c == " " and literal_spaces:
+                s.append(c)
+            elif c in _ALNUM:
                 s.append(c)
             elif c == "\x00":
                 s.append("\\000")
